@@ -137,18 +137,18 @@ class Insight_Definition:
 
         settings = {}
         for field in field_codes.keys():
+            ids = []
             for column in columns:
-                if(column["code"] in field_codes[field]):
+                if(column["code"] in field_codes[field] or column["name"] in field_codes[field]):
                     for query in query_ids:
                         if(str(field_codes[field]).startswith(query)):
                            if(str(column["id"]).startswith(query)):
-                               settings[field + "_id"] = column["id"]
-                               break
+                               ids.append(column["id"])
                            else:
                                continue
                         else:
-                            settings[field + "_id"] = column["id"]
-                            break
+                            settings[field + "_id"] = ids.append(column["id"])
+
 
         for key in values.keys():
             settings[key + "_id"] = values[key]
@@ -167,6 +167,7 @@ class Insight_Definition:
             "valid": True,
             "queryComponent": False
         }
+        print(body)
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
